@@ -1,8 +1,18 @@
-## comparison of numerical approximation to the lattice sum for a 2D array of dipoles and its converged solution
 
+## ----load,message=FALSE--------------------------------------------------
 library(cda)
+library(rgl)
 library(ggplot2)
+library(reshape2)
+library(plyr)
+library(knitr)
 
+
+## ----setup,echo=FALSE----------------------------------------------------
+theme_set(theme_minimal())
+
+
+## ----comparison,echo=TRUE,tidy=FALSE,fig.path="array-",fig.width=10, warning=FALSE----
 data(G0)
 
 ## number of dipoles for the numerical evaluation
@@ -16,7 +26,6 @@ lambdap <- lambda / pitch
 S1 <- array_factor(wavelength=lambda,
                    N=N, pitch=pitch)
 
-
 interpolate.fun <- function(x, y){
   list(re=approxfun(x, Re(y)),
        im=approxfun(x, Im(y)))
@@ -24,21 +33,23 @@ interpolate.fun <- function(x, y){
 
 gfun <- interpolate.fun(G0$wavelength, G0$Gxx)
 
-
-results <- data.frame(lambdap = S1$wavelength / pitch,
+numerical <- data.frame(lambdap = S1$wavelength / pitch,
                       real = Re(S1$S)*pitch^3,
                       imag = Im(S1$S)*pitch^3,
                       method = "truncated")
 
-javier <- data.frame(lambdap = lambdap,
+converged <- data.frame(lambdap = lambdap,
                      real = gfun$re(lambdap),
                      imag = gfun$im(lambdap),
                      method = "converged")
-
-p <- ggplot(melt(rbind(results, javier), id = c("lambdap", "method")),
+m <- melt(rbind(converged, numerical), id = c("lambdap", "method"))
+p <- ggplot(m,
             aes(lambdap, value, colour=variable, linetype=method)) +
   geom_vline(xintercept = c(1, sqrt(2)/2), linetype=2, colour="grey")+
-  geom_path() + theme_bw() + labs(x=expression("reduced wavelength "*lambda/nh), y=expression(S/h^3))
+  geom_line() +  
+  geom_path(data=subset(m, method == "converged"),size=1) + 
+  coord_cartesian(ylim=c(-500, 1000)) +
+  labs(x=expression("reduced wavelength "*lambda/nh), y=expression(S/h^3))
 
 p
 
